// This Source Code Form is subject to the terms of the Mozilla Public
// License, v. 2.0. If a copy of the MPL was not distributed with this
// file, You can obtain one at http://mozilla.org/MPL/2.0/.
import { resolveSelf, find } from './utilities';
var Disposition = /** @class */ (function () {
    function Disposition(moduleName, options) {
        this.moduleName = moduleName;
        this.options = options;
        this.filenames = [
            this.moduleName + ".config.js",
            this.moduleName + ".config.ts",
            this.moduleName + ".config.tsx",
        ];
    }
    /** Search for and load the configuation file. */
    Disposition.prototype.load = function () {
        var configPath = find(process.cwd(), this.filenames);
        if (configPath) {
            if (this.options) {
                if (this.options.project) {
                    return _load(configPath, this.options.project);
                }
            }
            return _load(configPath);
        }
        else {
            return undefined;
        }
    };
    return Disposition;
}());
export default Disposition;
function _load(configPath, project) {
    if (project === void 0) { project = resolveSelf('tsconfig.json'); }
    require('ts-node').register({
        project: project,
        // Ensure that the version of TypeScript shipped with Disposition is
        // used.
        compiler: require.resolve('typescript'),
        compilerOptions: {
            target: 'es5',
            // The project should have ES modules enabled for Webpack to
            // consume and tree-shake. However, since the config is run by
            // NodeJS, which does not support ES modules, we need to
            // compile required TypeScript files to CommonJS instead.
            module: 'commonjs',
            jsx: 'react',
            // Avoid problems with tslib being missing by simply disabling
            // import helpers.
            importHelpers: false,
            // Allow compiling and running files written in JavaScript.
            allowJs: true,
        },
        ignore: ['/node_modules/'],
    });
    return require(configPath).default;
}

//# sourceMappingURL=disposition.js.map
