// This Source Code Form is subject to the terms of the Mozilla Public
// License, v. 2.0. If a copy of the MPL was not distributed with this
// file, You can obtain one at http://mozilla.org/MPL/2.0/.
import * as fs from 'fs';
import * as path from 'path';
var selfDirectory = fs.realpathSync(path.join(__dirname, '../..'));
/**
 * Resolve a path relative to Dispositions's package root.
 *
 * @param relativePath The path relative to the package root.
 */
export function resolveSelf(relativePath) {
    return path.resolve(selfDirectory, relativePath);
}
/**
 * Search for a specific set of files by walking up the directory tree
 * and returning the full path to the first file that matches one of
 * the provided filenames.
 *
 * @param directory The directory to start from.
 * @param filenames The filenames to search for.
 */
export function find(directory, filenames) {
    var directoryPath = fs.realpathSync(directory);
    // Retrieve a list of the files in the current directory.
    var files = fs.readdirSync(directoryPath);
    // Iterate over the list of files and check if any match a filename
    // we are looking for.
    for (var _i = 0, files_1 = files; _i < files_1.length; _i++) {
        var file = files_1[_i];
        for (var _a = 0, filenames_1 = filenames; _a < filenames_1.length; _a++) {
            var filename = filenames_1[_a];
            if (file === filename) {
                return fs.realpathSync(path.resolve(directoryPath, file));
            }
        }
    }
    // If we have hit the top of the directory tree, return null.
    if (directoryPath === '/') {
        return null;
    }
    // If we have reached this statement, we have not found the
    // filename we are looking for in the current directory, so we run
    // the function again one directory up the tree.
    return find(path.resolve(directoryPath, '..'), filenames);
}

//# sourceMappingURL=utilities.js.map
